build_by_network: Build a network where entities share values from another...

View source: R/co-network.R

build_by_networkR Documentation

Build a network where entities share values from another field

Description

Build a network where entities share values from another field

Usage

build_by_network(
  data,
  field,
  by,
  counting,
  similarity,
  threshold,
  min_occur,
  top_n = NULL,
  self_loops = FALSE,
  deduplicate = TRUE,
  strip_quotes = TRUE
)

bibnets documentation built on June 19, 2026, 1:06 a.m.