resolve_paths: Resolve file paths from a file, vector of files, or directory

View source: R/read-biblio.R

resolve_pathsR Documentation

Resolve file paths from a file, vector of files, or directory

Description

Resolve file paths from a file, vector of files, or directory

Usage

resolve_paths(path)

bibnets documentation built on June 19, 2026, 1:06 a.m.