to_igraph: Convert edge data frame to igraph

View source: R/converters.R

to_igraphR Documentation

Convert edge data frame to igraph

Description

Convert edge data frame to igraph

Usage

to_igraph(edges, directed = FALSE)

Arguments

edges

A data frame with at least from, to, weight columns, as returned by any network function in bibnets.

directed

Logical. Default FALSE.

Value

An igraph graph object.

Examples


data(biblio_data)
edges <- author_network(biblio_data, "collaboration")
g <- to_igraph(edges)


bibnets documentation built on June 19, 2026, 1:06 a.m.