| build_author_bipartite | R Documentation |
For position-dependent counting methods, this replaces the binary bipartite matrix entries with positional weights derived from author order.
build_author_bipartite(
data,
field = "authors",
counting = "full",
position_weights = c(1, 0.8, 0.6, 0.4),
first_last_weight = 2,
deduplicate = TRUE,
sep = ";",
strip_quotes = TRUE
)
data |
A data frame with |
counting |
Character. Counting method. |
position_weights |
Numeric vector for |
first_last_weight |
Numeric for |
A sparse weighted bipartite matrix (works x authors).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.