| filter_top | R Documentation |
Keeps only edges between the most frequent nodes. Node frequency is determined by how many edges each node participates in.
filter_top(edges, n)
edges |
A data frame with at least |
n |
Integer. Number of top nodes to keep. |
A filtered data frame with edges among the top n nodes.
data(biblio_data)
edges <- author_network(biblio_data, "collaboration")
# Keep only edges among the top 3 most connected authors
filter_top(edges, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.