View source: R/historiograph.R
| local_citations | R Documentation |
Counts how many times each document is cited by other documents within the dataset.
local_citations(
data,
references = "references",
sep = ";",
strip_quotes = TRUE,
id = NULL
)
data |
A data frame with |
references |
Character. Name of the column containing cited references.
Default |
sep |
Character. Separator used to split the references column when it is a plain
character column. Default |
strip_quotes |
Logical. If |
id |
Optional. Name of the column to use as the work identifier.
If |
A data frame with columns:
idDocument identifier.
lcsLocal Citation Score: times cited within the dataset.
gcsGlobal Citation Score: cited_by_count if available.
Plus any metadata columns present in the input (title, year,
journal, doi).
data(biblio_data)
local_citations(biblio_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.